@@ -2,8 +2,11 @@
  * Plots a time series of data, with configurable number of lines and names.
  */
 
+if (typeof MsgBasePlot !== "undefined") {
+    console.log('MsgBasePlot already loaded');
+} else {
 var svgns = "http://www.w3.org/2000/svg";
-class BasePlot extends HTMLElement {
+class MsgBasePlot extends HTMLElement {
     constructor() {
         super();
 
@@ -40,7 +43,11 @@ svg {
 }`;
         this.shadow.appendChild(style);
         
-        this.timeLimit = parseFloat(this.getAttribute('timeLimit')); // seconds
+        if(this.hasAttribute('timeLimit')) {
+            this.timeLimit = parseFloat(this.getAttribute('timeLimit')); // seconds
+        } else {
+            this.timeLimit = 20.0;
+        }
         this.duration = 750;
         if(this.hasAttribute('yMin') || this.hasAttribute('yMax')) {
             this.yMin = parseFloat(this.getAttribute('yMin'));
@@ -55,20 +62,10 @@ svg {
         // #a09344
         // #7f64b9
         // #c36785
-        let labels = this.getAttribute('labels').split(",");
-        let colors = ['rgb(219,109,0)', '#000000', 'rgb(0,109,219)', 'rgb(109,219,0)','rgb(109,0,219)'];
-        var color=0;
         this.dataSets = {};
-        for (var i in labels) {
-            var label = labels[i];
-            this.dataSets[label] = {
-                value: 0,
-                color: colors[color],
-                data: [],
-                pathData: [],
-                name: label
-            }
-            color++;
+        if(this.hasAttribute('labels')) {
+            let labels = this.getAttribute('labels').split(",");
+            this.configureDataSets(labels);
         }
         this.timestamps = [];
 
@@ -85,6 +82,23 @@ svg {
         window.addEventListener('visibilitychange', this.resize.bind(this));
         this.resize();
     }
+    
+    configureDataSets(labels)
+    {
+        let colors = ['red','blue','green','orange','purple','hotpink','cyan','limegreen','magenta','darkred','darkblue','darkgreen','darkorange','darkpurple'];
+        var color=0;
+        for (var i in labels) {
+            var label = labels[i];
+            this.dataSets[label] = {
+                value: 0,
+                color: colors[color],
+                data: [],
+                pathData: [],
+                name: label
+            }
+            color++;
+        }
+    }
 
     resize()
     {
@@ -282,4 +296,6 @@ svg {
 // tag have been defined, so that our calls to getAttribute will succeed.
 // (Also after any remaining dependencies are loaded.)
 // Best plan is just to import this whole file at the end of your HTML.
-customElements.define('msgtools-plot', BasePlot);
+customElements.define('msgtools-plot', MsgBasePlot);
+window.MsgBasePlot = MsgBasePlot;
+}
